# Release Notes for Ext JS 3.3.1

Release Date: November 30, 2010
Current Version: 3.3.1 (rev 7296/265)
Previous Version: 3.3.0 (rev 7233/263)

## Changes

### Forms

- Added a null check before trying to access getGroupValue.
- Ext.form.updateRecord() now checks for null value from getValue().
- Ext.form.updateRecord() now checks for null value from getValue().
Combobox now returns correct value when non-unique display fields are used.

### CSS

- Remove :hover pseudo on color-palette.
- Update CSS to fix tab panel under IE8.
- Fix TwinTriggerField rendering in WebKit browsers.
- Add missing sort indicator image for the gray theme (for listview).
- Fix border layout collapsed icon position for IE in quirks mode.
- Pivot panel now works with the gray theme.

### Data

- For XmlReader, added the ability to use a function for a mapping, same as JsonReader.
- Cleanup variables in store.

### Date

- Fix a that causes date parsing to fail when AM/PM is included before the time part.

### Grid

- Fix issues relating to correctly restoring grid state.
- For GridView, update the event to ensure it passes the grid, not the view.
- rowsinserted event now properly fires after the insert is complete.

### Misc

- Added changelog.html to distribution.
- Removed redundant field labels from CompositeField example.
- In case of an action, defaults are now applied to the initialConfig and not to the action itself.
- Container's resizeEvent event is now removed on destroy.
- Fix an issue where rows would be selected by the editor even if checkOnly was set to true.
- A disabled spinner will no longer spin.
- Added missing panel tools: x-tool-(prev|next|expand|collapse).

### Locale

- For French, Ext.util.Format.plural now considers 0 to be singular.
- Adds startDay to DateField.prototype for locale files having startDay already defined for DatePicker.prototype.
- Added Amharic (Ethopian) language support ext-lang-am.js.